NLSL: basis Module Reference

NLSL

- Main Page
- Modules
- Data Types List
- Files

- Modules List
- Module Members

Variables
basis Module Reference

## Variables
integer, dimension(5, mxdim), save | ibasis
integer, dimension(mxsite, mxspc), save | basno
integer, dimension(9, mxmts), save | mts
integer, dimension(mxtdm), save | ixbas
integer, dimension(mxtdm), save | ltbas
integer, dimension(mxtdm), save | bsused
integer, save | nbas
integer, save | nextbs
character *30, dimension(mxtdm), save | basisid

## Variable Documentation

character*30, dimension(mxtdm), save basis::basisid

Definition at line 27 of file basis.f90.

integer, dimension(mxsite,mxspc), save basis::basno

Definition at line 23 of file basis.f90.

integer, dimension(mxtdm), save basis::bsused

Definition at line 23 of file basis.f90.

integer, dimension(5,mxdim), save basis::ibasis

Definition at line 23 of file basis.f90.

integer, dimension(mxtdm), save basis::ixbas

Definition at line 23 of file basis.f90.

integer, dimension(mxtdm), save basis::ltbas

Definition at line 23 of file basis.f90.

integer, dimension(9,mxmts), save basis::mts

Definition at line 23 of file basis.f90.

integer, save basis::nbas

Definition at line 23 of file basis.f90.

integer, save basis::nextbs

Definition at line 23 of file basis.f90.